pub struct ContextDiff {
pub to_add: Vec<SubstitutionLink>,
pub to_remove: Vec<SubstitutionLink>,
pub conflicting: Vec<LinkConflict>,
}Expand description
The difference between two contexts’ world states (STRIPS goal − state).
Fields
to_add: Vec<SubstitutionLink>Links present in the target but missing from the current context.
to_remove: Vec<SubstitutionLink>Links present in the current context but missing from the target.
conflicting: Vec<LinkConflict>Same-from, different-to conflicts between the two contexts.
Implementations
Sourceimpl ContextDiff
impl ContextDiff